Struct SoftwareSha256
Source pub struct SoftwareSha256;
Hash a list of borrowed byte slices as one concatenated message.
Compute HMAC-SHA-256 over a list of borrowed byte slices.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.