Struct CmacState
Source pub struct CmacState<C: AesCipher> { }
Incremental AES-CMAC state.
Initialize a new incremental CMAC state.
Feed additional bytes into the MAC state.
Finalize and return the full 16-byte CMAC value.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.